;;; DO NOT MODIFY THIS FILE
(if (featurep 'Sun-autoloads) (error "Already loaded"))

;;;### (autoloads nil "_pkg" "Sun/_pkg.el")

(package-provide 'Sun :version 1.05 :type 'regular)

;;;***

(provide 'Sun-autoloads)
