(setq package-lisp
      '(
	;; #+sparcworks "cc-mode" ; Requires cc-mode package
	;; cc-mode > 5.21 is fucked up and shouldn't be dumped
	#+sparcworks "sunpro-init"
	#+sparcworks "ring"
	#+sparcworks "comint" ; Requires comint package
	#+sparcworks "annotations"
))
